==> gmt_python_sdk-0.10.0.tar.gz: gmt_python_sdk-0.10.0/CHANGELOG.md <==
# Changelog

## 0.10.0 (2025-12-19)

Full Changelog: [v0.9.1...v0.10.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.9.1...v0.10.0)

### Features

* **api:** api update ([c34332a](https://github.com/cameo6/gmt-python-sdk/commit/c34332a8618301f5674dcf581e56bea5974a2c43))


### Chores

* **internal:** add `--fix` argument to lint script ([6479356](https://github.com/cameo6/gmt-python-sdk/commit/647935661dfca80dfdd23a8ee5edf945a15cf5d2))

## 0.9.1 (2025-12-18)

Full Changelog: [v0.9.0...v0.9.1](https://github.com/cameo6/gmt-python-sdk/compare/v0.9.0...v0.9.1)

### Bug Fixes

* use async_to_httpx_files in patch method ([01da89f](https://github.com/cameo6/gmt-python-sdk/commit/01da89fb6f5f397296cb14ba73339014b59317bd))


### Chores

* speedup initial import ([61ca4cf](https://github.com/cameo6/gmt-python-sdk/commit/61ca4cf2538df91511c37987784aee18dc1e1ea6))


### Refactors

* **internal:** switch from rye to uv ([8790e4c](https://github.com/cameo6/gmt-python-sdk/commit/8790e4c2f0c0736777981ec7be27d827005a0fce))

## 0.9.0 (2025-12-16)

Full Changelog: [v0.8.1...v0.9.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.8.1...v0.9.0)

### Features

* **api:** api update ([9c51a24](https://github.com/cameo6/gmt-python-sdk/commit/9c51a2476545a87b6e9fdca7a08146622481cd79))


### Chores

* add missing docstrings ([5088121](https://github.com/cameo6/gmt-python-sdk/commit/5088121003e1f2bd957b032eb6ed5feb69845e7c))
* **internal:** add missing files argument to base client ([6670116](https://github.com/cameo6/gmt-python-sdk/commit/6670116e267787988bf6a7f8a2a63033ee5465ee))

## 0.8.1 (2025-12-09)

Full Changelog: [v0.8.0...v0.8.1](https://github.com/cameo6/gmt-python-sdk/compare/v0.8.0...v0.8.1)

### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([58aeecc](https://github.com/cameo6/gmt-python-sdk/commit/58aeecc79443b9b01525e4fee4175a17d032de39))

## 0.8.0 (2025-12-08)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.7.0...v0.8.0)

### Features

* **api:** api update ([3def11a](https://github.com/cameo6/gmt-python-sdk/commit/3def11a05f9c92676f251e7a2af305fa2be5d5bc))

## 0.7.0 (2025-12-08)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.6.0...v0.7.0)

### Features

* **api:** add refund repository ([d8db552](https://github.com/cameo6/gmt-python-sdk/commit/d8db552d131f6c5ef561b525a88ddb640367f381))

## 0.6.0 (2025-12-08)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.5.0...v0.6.0)

### Features

* **api:** api update ([67ec995](https://github.com/cameo6/gmt-python-sdk/commit/67ec995a28fb98f9e262bf599c0549e0cdae73ba))

## 0.5.0 (2025-12-08)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.4.0...v0.5.0)

### Features

* **api:** add webhooks endpoint ([eb61be5](https://github.com/cameo6/gmt-python-sdk/commit/eb61be5bdfde7153dc653d265893f5c1ef21b4ca))

## 0.4.0 (2025-12-08)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.3.0...v0.4.0)

### Features

* **api:** api update ([6fd4046](https://github.com/cameo6/gmt-python-sdk/commit/6fd4046e10082492f50987970e6880390272ba37))


### Chores

* update lockfile ([dbbf2e9](https://github.com/cameo6/gmt-python-sdk/commit/dbbf2e9f243aa59dd4eb64246cab4eaec204f506))

## 0.3.0 (2025-11-28)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([3d8f73c](https://github.com/cameo6/gmt-python-sdk/commit/3d8f73c03a372b6bacad14b4925d1350fab12548))

## 0.2.0 (2025-11-28)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.1.0...v0.2.0)

### Features

* **api:** api update ([31f9595](https://github.com/cameo6/gmt-python-sdk/commit/31f9595ad1832708e52ebdd77acd34776e19a890))

## 0.1.0 (2025-11-28)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.0.1...v0.1.0)

### Features

* **api:** api update ([0ba3d7e](https://github.com/cameo6/gmt-python-sdk/commit/0ba3d7e4e9a87866e89d244fd6c7ca98a59236af))
* **api:** manual updates ([81d9f33](https://github.com/cameo6/gmt-python-sdk/commit/81d9f33de9f266d7c5e06379cf75d55a40f1366a))


### Bug Fixes

* ensure streams are always closed ([5ab47f0](https://github.com/cameo6/gmt-python-sdk/commit/5ab47f0219cc85563e6e7352e460cda9275f1601))


### Chores

* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([a1731e0](https://github.com/cameo6/gmt-python-sdk/commit/a1731e0758cf5de45fb93fd59fc03dbfbb1a806a))
* update SDK settings ([2d9f3a9](https://github.com/cameo6/gmt-python-sdk/commit/2d9f3a90bc50ded9e8df86031ffd6509852d9bd6))
* update SDK settings ([904acac](https://github.com/cameo6/gmt-python-sdk/commit/904acacb04e79821b2f5ac9990b09e8ec6bd8fdc))

==> gmt_python_sdk-0.11.0.tar.gz: gmt_python_sdk-0.11.0/CHANGELOG.md <==
# Changelog

## 0.11.0 (2026-01-14)

Full Changelog: [v0.10.0...v0.11.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.10.0...v0.11.0)

### Features

* **client:** add support for binary request streaming ([4630e55](https://github.com/cameo6/gmt-python-sdk/commit/4630e558cea821aaf9f4997ff14fdcf524951b29))


### Chores

* **internal:** codegen related update ([3c1fe79](https://github.com/cameo6/gmt-python-sdk/commit/3c1fe79d3b6ff994d9b238c9155095dc33668f62))

## 0.10.0 (2025-12-19)

Full Changelog: [v0.9.1...v0.10.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.9.1...v0.10.0)

### Features

* **api:** api update ([c34332a](https://github.com/cameo6/gmt-python-sdk/commit/c34332a8618301f5674dcf581e56bea5974a2c43))


### Chores

* **internal:** add `--fix` argument to lint script ([6479356](https://github.com/cameo6/gmt-python-sdk/commit/647935661dfca80dfdd23a8ee5edf945a15cf5d2))

## 0.9.1 (2025-12-18)

Full Changelog: [v0.9.0...v0.9.1](https://github.com/cameo6/gmt-python-sdk/compare/v0.9.0...v0.9.1)

### Bug Fixes

* use async_to_httpx_files in patch method ([01da89f](https://github.com/cameo6/gmt-python-sdk/commit/01da89fb6f5f397296cb14ba73339014b59317bd))


### Chores

* speedup initial import ([61ca4cf](https://github.com/cameo6/gmt-python-sdk/commit/61ca4cf2538df91511c37987784aee18dc1e1ea6))


### Refactors

* **internal:** switch from rye to uv ([8790e4c](https://github.com/cameo6/gmt-python-sdk/commit/8790e4c2f0c0736777981ec7be27d827005a0fce))

## 0.9.0 (2025-12-16)

Full Changelog: [v0.8.1...v0.9.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.8.1...v0.9.0)

### Features

* **api:** api update ([9c51a24](https://github.com/cameo6/gmt-python-sdk/commit/9c51a2476545a87b6e9fdca7a08146622481cd79))


### Chores

* add missing docstrings ([5088121](https://github.com/cameo6/gmt-python-sdk/commit/5088121003e1f2bd957b032eb6ed5feb69845e7c))
* **internal:** add missing files argument to base client ([6670116](https://github.com/cameo6/gmt-python-sdk/commit/6670116e267787988bf6a7f8a2a63033ee5465ee))

## 0.8.1 (2025-12-09)

Full Changelog: [v0.8.0...v0.8.1](https://github.com/cameo6/gmt-python-sdk/compare/v0.8.0...v0.8.1)

### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([58aeecc](https://github.com/cameo6/gmt-python-sdk/commit/58aeecc79443b9b01525e4fee4175a17d032de39))

## 0.8.0 (2025-12-08)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.7.0...v0.8.0)

### Features

* **api:** api update ([3def11a](https://github.com/cameo6/gmt-python-sdk/commit/3def11a05f9c92676f251e7a2af305fa2be5d5bc))

## 0.7.0 (2025-12-08)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.6.0...v0.7.0)

### Features

* **api:** add refund repository ([d8db552](https://github.com/cameo6/gmt-python-sdk/commit/d8db552d131f6c5ef561b525a88ddb640367f381))

## 0.6.0 (2025-12-08)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.5.0...v0.6.0)

### Features

* **api:** api update ([67ec995](https://github.com/cameo6/gmt-python-sdk/commit/67ec995a28fb98f9e262bf599c0549e0cdae73ba))

## 0.5.0 (2025-12-08)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.4.0...v0.5.0)

### Features

* **api:** add webhooks endpoint ([eb61be5](https://github.com/cameo6/gmt-python-sdk/commit/eb61be5bdfde7153dc653d265893f5c1ef21b4ca))

## 0.4.0 (2025-12-08)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.3.0...v0.4.0)

### Features

* **api:** api update ([6fd4046](https://github.com/cameo6/gmt-python-sdk/commit/6fd4046e10082492f50987970e6880390272ba37))


### Chores

* update lockfile ([dbbf2e9](https://github.com/cameo6/gmt-python-sdk/commit/dbbf2e9f243aa59dd4eb64246cab4eaec204f506))

## 0.3.0 (2025-11-28)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([3d8f73c](https://github.com/cameo6/gmt-python-sdk/commit/3d8f73c03a372b6bacad14b4925d1350fab12548))

## 0.2.0 (2025-11-28)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.1.0...v0.2.0)

### Features

* **api:** api update ([31f9595](https://github.com/cameo6/gmt-python-sdk/commit/31f9595ad1832708e52ebdd77acd34776e19a890))

## 0.1.0 (2025-11-28)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/cameo6/gmt-python-sdk/compare/v0.0.1...v0.1.0)

### Features

* **api:** api update ([0ba3d7e](https://github.com/cameo6/gmt-python-sdk/commit/0ba3d7e4e9a87866e89d244fd6c7ca98a59236af))
* **api:** manual updates ([81d9f33](https://github.com/cameo6/gmt-python-sdk/commit/81d9f33de9f266d7c5e06379cf75d55a40f1366a))


### Bug Fixes

* ensure streams are always closed ([5ab47f0](https://github.com/cameo6/gmt-python-sdk/commit/5ab47f0219cc85563e6e7352e460cda9275f1601))


### Chores

* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([a1731e0](https://github.com/cameo6/gmt-python-sdk/commit/a1731e0758cf5de45fb93fd59fc03dbfbb1a806a))
* update SDK settings ([2d9f3a9](https://github.com/cameo6/gmt-python-sdk/commit/2d9f3a90bc50ded9e8df86031ffd6509852d9bd6))
* update SDK settings ([904acac](https://github.com/cameo6/gmt-python-sdk/commit/904acacb04e79821b2f5ac9990b09e8ec6bd8fdc))
